aboutsummaryrefslogtreecommitdiffstats
path: root/packet-dcerpc.c
diff options
context:
space:
mode:
authortpot <tpot@f5534014-38df-0310-8fa8-9805f1628bb7>2003-09-26 04:43:05 +0000
committertpot <tpot@f5534014-38df-0310-8fa8-9805f1628bb7>2003-09-26 04:43:05 +0000
commita1e8bcda51f30ab908af875d909784b579bb7408 (patch)
tree144d4477d4357cef270eb27f2d190e02c45cb47b /packet-dcerpc.c
parentd399b8197a67321865c806ae4fd4bec31ea9e355 (diff)
Use zero to mean we haven't seen any authentication level information
in dcerpc_auth_info since auth_level is an unsigned type. Zero is not a valid authentication level anyway (s13.1.2.1, p611 CAE spec). Remove two inscrutable debugging comments that don't seem to mean anything. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@8545 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'packet-dcerpc.c')
-rw-r--r--packet-dcerpc.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/packet-dcerpc.c b/packet-dcerpc.c
index f1e288c6b7..23a32e8c62 100644
--- a/packet-dcerpc.c
+++ b/packet-dcerpc.c
@@ -3,7 +3,7 @@
* Copyright 2001, Todd Sabin <tas@webspan.net>
* Copyright 2003, Tim Potter <tpot@samba.org>
*
- * $Id: packet-dcerpc.c,v 1.140 2003/09/19 05:30:01 tpot Exp $
+ * $Id: packet-dcerpc.c,v 1.141 2003/09/26 04:43:05 tpot Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -1943,11 +1943,12 @@ dissect_dcerpc_cn_auth (tvbuff_t *tvb, packet_info *pinfo, proto_tree *dcerpc_tr
int offset;
/*
* Initially set auth_level to -1 to indicate that we haven't
* yet seen any authentication level information.
*/
- auth_info->auth_level = -1;
-
+ auth_info->auth_level = 0;
+ auth_info->auth_type = 0;
+
/*
* The authentication information is at the *end* of the PDU; in
* request and response PDUs, the request and response stub data
@@ -2696,7 +2697,7 @@ dissect_dcerpc_cn_rqst (tvbuff_t *tvb, gint offset, packet_info *pinfo,
proto_tree_add_uint(dcerpc_tree, hf_dcerpc_response_in,
tvb, 0, 0, value->rep_frame);
}
-/*qqq request, broken*/
+
dissect_dcerpc_cn_stub (tvb, offset, pinfo, dcerpc_tree, tree,
hdr, di, &auth_info, alloc_hint,
value->req_frame);
@@ -2799,7 +2800,6 @@ dissect_dcerpc_cn_resp (tvbuff_t *tvb, gint offset, packet_info *pinfo,
proto_tree_add_time(dcerpc_tree, hf_dcerpc_time, tvb, offset, 0, &ns);
}
-/*qqq response ok*/
dissect_dcerpc_cn_stub (tvb, offset, pinfo, dcerpc_tree, tree,
hdr, di, &auth_info, alloc_hint,
value->rep_frame);
@@ -1943,11 +1943,12 @@ dissect_dcerpc_cn_auth (tvbuff_t *tvb, packet_info *pinfo, proto_tree *dcerpc_tr
int offset;
/*
- * Initially set auth_level to -1 to indicate that we haven't
- * yet seen any authentication level information.
+ * Initially set auth_level and auth_type to zero to indicate that we
+ * haven't yet seen any authentication level information.
*/